==> jc-1.4.0.tar.gz: java/nio/channels/spi/AbstractSelectionKey.h <==
// public abstract class java.nio.channels.spi.AbstractSelectionKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header java_nio_channels_SelectionKey

#include "java/nio/channels/SelectionKey.h"

#ifndef _JC_java_nio_channels_spi_AbstractSelectionKey_H_
#define _JC_java_nio_channels_spi_AbstractSelectionKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	_jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	_jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$refs	_jc_java_nio_channels_spi_AbstractSelectionKey$refs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs	_jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$object	_jc_java_nio_channels_spi_AbstractSelectionKey$object;

typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods;
typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtable	_jc_java_nio_channels_spi_AbstractSelectionKey$vtable;
typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtype	_jc_java_nio_channels_spi_AbstractSelectionKey$vtype;

// Constructors
extern void _jc_java_nio_channels_spi_AbstractSelectionKey$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *);

// Virtual methods
extern void _jc_java_nio_channels_spi_AbstractSelectionKey$method$cancel$8d1adbad6fd0b0c5(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *);
extern jboolean _jc_java_nio_channels_spi_AbstractSelectionKey$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_AbstractSelectionKey$method_info$cancel$8d1adbad6fd0b0c5;
extern _jc_method _jc_java_nio_channels_spi_AbstractSelectionKey$method_info$isValid$835d853ce0a23705;

// Virtual methods structure
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vmethods {
	void	(*cancel$8d1adbad6fd0b0c5)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *);
};

// Vtable
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
};

// Vtype
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$refs {
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs {
	jboolean	cancelled;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
};

// Object instance structure
struct _jc_java_nio_channels_spi_AbstractSelectionKey$object {
	_jc_java_nio_channels_spi_AbstractSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vtype	*vtype;
	_jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_AbstractSelectionKey$vtype _jc_java_nio_channels_spi_AbstractSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_AbstractSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_AbstractSelectionKey$class_object;

#endif	/* _JC_java_nio_channels_spi_AbstractSelectionKey_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/spi/AbstractSelectionKey.h <==
// public abstract class java.nio.channels.spi.AbstractSelectionKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78dea1137fb244b3 java_nio_channels_SelectionKey
// @dep_class c9ba919e4c66ad44 java_nio_channels_spi_AbstractSelectionKey

// header file dependencies
// @dep_header java_nio_channels_SelectionKey

#include "java/nio/channels/SelectionKey.h"

#ifndef _JC_java_nio_channels_spi_AbstractSelectionKey_H_
#define _JC_java_nio_channels_spi_AbstractSelectionKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	_jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	_jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$refs	_jc_java_nio_channels_spi_AbstractSelectionKey$refs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs	_jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs;
typedef struct _jc_java_nio_channels_spi_AbstractSelectionKey$object	_jc_java_nio_channels_spi_AbstractSelectionKey$object;

typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods;
typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtable	_jc_java_nio_channels_spi_AbstractSelectionKey$vtable;
typedef const struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtype	_jc_java_nio_channels_spi_AbstractSelectionKey$vtype;

// Constructors
extern void _jc_java_nio_channels_spi_AbstractSelectionKey$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_nio_channels_spi_AbstractSelectionKey$method$cancel$8d1adbad6fd0b0c5(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_nio_channels_spi_AbstractSelectionKey$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_spi_AbstractSelectionKey$method_info$cancel$8d1adbad6fd0b0c5;
extern _jc_method _jc_java_nio_channels_spi_AbstractSelectionKey$method_info$isValid$835d853ce0a23705;

// Virtual methods structure
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vmethods {
	void	(*cancel$8d1adbad6fd0b0c5)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_java_nio_channels_spi_AbstractSelectionKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_SelectionKey$vmethods	java_nio_channels_SelectionKey;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vmethods	java_nio_channels_spi_AbstractSelectionKey;
};

// Vtype
struct _jc_java_nio_channels_spi_AbstractSelectionKey$vtype {
	_jc_type			type;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$refs {
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_refs	java_nio_channels_spi_AbstractSelectionKey;
    _jc_java_nio_channels_SelectionKey$sub_refs	java_nio_channels_SelectionKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs {
	jboolean	cancelled;
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_SelectionKey$sub_nonrefs	java_nio_channels_SelectionKey;
    _jc_java_nio_channels_spi_AbstractSelectionKey$sub_nonrefs	java_nio_channels_spi_AbstractSelectionKey;
};

// Object instance structure
struct _jc_java_nio_channels_spi_AbstractSelectionKey$object {
	_jc_java_nio_channels_spi_AbstractSelectionKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_spi_AbstractSelectionKey$vtype	*vtype;
	_jc_java_nio_channels_spi_AbstractSelectionKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_spi_AbstractSelectionKey$vtype _jc_java_nio_channels_spi_AbstractSelectionKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_spi_AbstractSelectionKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_spi_AbstractSelectionKey$class_object;

#endif	/* _JC_java_nio_channels_spi_AbstractSelectionKey_H_ */
